package com.example.tracktrek;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.StreamCorruptedException;
import java.text.DecimalFormat;
import java.util.Arrays;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.graphics.Color;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Shader;
import android.os.Bundle;
import android.util.Log;

import com.androidplot.Plot;
import com.androidplot.series.XYSeries;
import com.androidplot.xy.LineAndPointFormatter;
import com.androidplot.xy.SimpleXYSeries;
import com.androidplot.xy.XYPlot;
import com.androidplot.xy.XYStepMode;

/*
 * ElevationGraph is passed route information from the PreviousRoutes activity
 * and used the elevation information to create an elevation graph of the user's 
 * route.
 */

public class ElevationGraph extends Activity {

	private XYPlot AltPlot;
	private int BONE = 0xFFF4F5E9;
	private int DARKBLUE = 0xFF273F6F;
	private int LIGHTBLUE = 0XFFE1E6F0;

	private double pre;
	private double preA[];
	private Number Altitude[];
	private double t;
	private Number Time[];
	private int iTime[];

	// Determine Color Resolution & Apply it
	private double AltHigh = 0.1;
	private double AltLow = 10000.1;
	private int length;

	@SuppressLint("NewApi")
	@Override
	public void onCreate(Bundle savedInstanceState) {

		super.onCreate(savedInstanceState);
		Intent intent = getIntent();
		String fileName = intent.getStringExtra(PreviousRoutes.Selected_File);
		FileInputStream fis;
		try {
			// The next line is where you give the name of file you want to read
			fis = openFileInput(fileName);
			ObjectInputStream ois = new ObjectInputStream(fis);

			Object RouteGPS[] = (Object[]) ois.readObject();
			Object Route[] = (Object[]) ois.readObject();
			ois.close();
			length = Route.length;
			preA = new double[length];
			Altitude = new Number[length];
			Time = new Number[length];
			iTime = new int[length];
			// Extract Time & Pressure

			for (int i = 0; i < length; i++) {
				pre = ((locationData) Route[i]).pressure;
				preA[i] = pre;
				Altitude[i] = pre;
				t = ((locationData) Route[i]).timestamp;
				Time[i] = i;
				iTime[i] = i;
				System.out.println(Altitude[i]);
				System.out.println(iTime[i]);

				// System.out.println( ((locationData)Route[i]).latitude ); Used
				// for Testing

				if (preA[i] > AltHigh) {
					AltHigh = preA[i];
				} else if (preA[i] < AltLow) {
					AltLow = preA[i];
				}

			}

		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (StreamCorruptedException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (ClassNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		setContentView(R.layout.activity_elevation_graph);
		setRequestedOrientation(Configuration.ORIENTATION_LANDSCAPE);
		// initialize our XYPlot reference:
		AltPlot = (XYPlot) findViewById(R.id.AltitudePlot);
		// Set Margins & Padding
		AltPlot.setPlotMargins(0, 0, 0, 0);
		AltPlot.setPlotPadding(0, 0, 0, 0);
		AltPlot.getGraphWidget().setMarginTop(10);
		AltPlot.getGraphWidget().setMarginRight(4);
		AltPlot.getGraphWidget().setMarginBottom(4);
		// No Border
		AltPlot.setBorderStyle(Plot.BorderStyle.SQUARE, null, null);
		AltPlot.setBorderStyle(Plot.BorderStyle.NONE, null, null);
		// Set Grid Color
		AltPlot.getGraphWidget().getGridBackgroundPaint().setColor(BONE);
		// Set Background to Black
		AltPlot.getGraphWidget().getBackgroundPaint().setColor(Color.BLACK);
		// Set Grid Line Color
		AltPlot.getGraphWidget().getGridDomainLinePaint().setColor(LIGHTBLUE);
		AltPlot.getGraphWidget().getGridRangeLinePaint().setColor(LIGHTBLUE);
		// Domain Format
		AltPlot.setDomainLabel("Time");
		AltPlot.setDomainValueFormat(new DecimalFormat("#"));
		// Range Format
		AltPlot.setRangeLabel("Height");
		AltPlot.setRangeValueFormat(new DecimalFormat("#"));
		// Turn Legend Off by making it invisible
		AltPlot.getLegendWidget().setHeight(0);
		// Create arrays to plot:

		// Turn the above arrays into XYSeries:
		XYSeries Series = new SimpleXYSeries(Arrays.asList(Time),
				Arrays.asList(Altitude), "Altitude");
		// Create gradient fill:
		Paint lineFill = new Paint();
		lineFill.setAlpha(220);
		lineFill.setShader(new LinearGradient(0, 0, 0, 1000, BONE, DARKBLUE,
				Shader.TileMode.MIRROR));
		// Create a formatter to use for drawing a series using
		// LineAndPointRenderer:
		LineAndPointFormatter Format = new LineAndPointFormatter(Color.rgb(15,
				36, 60), // line color
				Color.rgb(99, 23, 9), // point color
				Color.rgb(15, 36, 60));// fill color
		// Assign gradient to Format
		Format.setFillPaint(lineFill);
		// add Series to the Plot:
		AltPlot.addSeries(Series, Format);
		// reduce the number of range labels
		AltPlot.setTicksPerRangeLabel(3);
		// get rid of developer guides:
		AltPlot.disableAllMarkup();

	}
}
